==> queueshare-0.0.55.tgz: package/src/qcSkipForward.js <==
import QcSkipBackPositions from './QcSkipBackPositions.js'
import CollabPosition from './CollabPosition.js'
import qcQueueMap from './qcQueueMap.js'
import QcRecentsPositions from './QcRecentsPositions.js'
import QcQueuePositions from './QcQueuePositions.js'
import qcsCollabMap from './qcsCollabMap.js'

const qcSkipForward = () => {
	const queuePositions = QcQueuePositions()
	if (queuePositions.length) {
		const currentPlaylistOrUndefined = qcQueueMap.get(queuePositions[0]).playlist
		const currentTrack = qcQueueMap.get(queuePositions[0]).track
		const skipBackPositions = QcSkipBackPositions()
		const recentsPositions = QcRecentsPositions()
		if (currentPlaylistOrUndefined === undefined) {
			const queueInfo = JSON.parse(qcsCollabMap.get('media-' + currentTrack + '-queueInfo'))
			qcsCollabMap.delete('media-' + currentTrack + '-queueInfo')
			qcsCollabMap.set('media-' + currentTrack + '-skipBackInfo', JSON.stringify({...queueInfo, position: CollabPosition(skipBackPositions.length ? skipBackPositions[skipBackPositions.length - 1] : null, null)}))
			qcsCollabMap.set('media-' + currentTrack + '-recentsInfo', JSON.stringify({position: CollabPosition(null, recentsPositions.length === 0 ? null : recentsPositions[0]), time: Date.now()}))
		} else {
			const currentPlaylist = currentPlaylistOrUndefined
			const queueInfo = JSON.parse(qcsCollabMap.get('media-' + currentTrack + '-playlists-' + currentPlaylist + '-queueInfo'))
			qcsCollabMap.delete('media-' + currentTrack + '-playlists-' + currentPlaylist + '-queueInfo')
			qcsCollabMap.set('media-' + currentTrack + '-playlists-' + currentPlaylist + '-skipBackInfo', JSON.stringify({...queueInfo, position: CollabPosition(skipBackPositions.length ? skipBackPositions[skipBackPositions.length - 1] : null, null)}))
			qcsCollabMap.set('media-' + currentPlaylist + '-recentsInfo', JSON.stringify({position: CollabPosition(null, recentsPositions.length === 0 ? null : recentsPositions[0]), time: Date.now()}))
		}
	}
}

export default qcSkipForward

==> queueshare-0.0.57.tgz: package/src/qcSkipForward.js <==
import QcPlayHistoryPositions from './QcPlayHistoryPositions.js'
import CollabPosition from './CollabPosition.js'
import qcQueueMap from './qcQueueMap.js'
import QcRecentsPositions from './QcRecentsPositions.js'
import QcQueuePositions from './QcQueuePositions.js'
import qcsCollabMap from './qcsCollabMap.js'

const qcSkipForward = () => {
	const queuePositions = QcQueuePositions()
	if (queuePositions.length) {
		const currentPlaylistOrUndefined = qcQueueMap.get(queuePositions[0]).playlist
		const currentTrack = qcQueueMap.get(queuePositions[0]).track
		const skipBackPositions = QcPlayHistoryPositions()
		const recentsPositions = QcRecentsPositions()
		if (currentPlaylistOrUndefined === undefined) {
			const queueInfo = JSON.parse(qcsCollabMap.get('media-' + currentTrack + '-queueInfo'))
			qcsCollabMap.delete('media-' + currentTrack + '-queueInfo')
			qcsCollabMap.set('media-' + currentTrack + '-skipBackInfo', JSON.stringify({...queueInfo, position: CollabPosition(skipBackPositions.length ? skipBackPositions[skipBackPositions.length - 1] : null, null)}))
			qcsCollabMap.set('media-' + currentTrack + '-recentsInfo', JSON.stringify({position: CollabPosition(null, recentsPositions.length === 0 ? null : recentsPositions[0]), time: Date.now()}))
		}
		else {
			const currentPlaylist = currentPlaylistOrUndefined
			const queueInfo = JSON.parse(qcsCollabMap.get('media-' + currentTrack + '-playlists-' + currentPlaylist + '-queueInfo'))
			qcsCollabMap.delete('media-' + currentTrack + '-playlists-' + currentPlaylist + '-queueInfo')
			qcsCollabMap.set('media-' + currentTrack + '-playlists-' + currentPlaylist + '-skipBackInfo', JSON.stringify({...queueInfo, position: CollabPosition(skipBackPositions.length ? skipBackPositions[skipBackPositions.length - 1] : null, null)}))
			qcsCollabMap.set('media-' + currentPlaylist + '-recentsInfo', JSON.stringify({position: CollabPosition(null, recentsPositions.length === 0 ? null : recentsPositions[0]), time: Date.now()}))
		}
		const playCountKey = 'media-' + currentTrack + '-playCount'
		const playCount = qcsCollabMap.has(playCountKey) ? JSON.parse(qcsCollabMap.get(playCountKey)) : 0
		qcsCollabMap.set(playCountKey, JSON.stringify(playCount + 1))
	}
}

export default qcSkipForward
